==> breeze_website_builder_6.5.0.tar.gz: manage/plugins/lang/gallery/hr.php <==
<?php
////////////////////////////////////////////////////////////////////////
// Breeze Website Builder
// Copyright Silver Dolphin Solutions, LLC, Edward Lemmers, P.E.
// For licensing, see license.txt.
// Created: 3/1/2015	ELL

///////////////////////// Manage Gallery Parameters /////////////////////////
// Buttons:
define('MANAGE_GALLERY_HEADING', "Upravljanje Lightbox gallary Parametri");
define('MANAGE_GALLERY_MANAGE_GALLERY_BTN', "Upravljanje galerija");
// Console Text:
define('MANAGE_GALLERY_FULL_WIDTH', "U punoj veličini Širina slike");
define('MANAGE_GALLERY_FULL_HEIGHT', "U punoj veličini Visina slike");
define('MANAGE_GALLERY_THUMB_WIDTH', "Minijatura Širina slike");
define('MANAGE_GALLERY_THUMB_HEIGHT', "Minijatura Visina slike");
define('MANAGE_GALLERY_PRESERVE_THUMB_ASPECT', "Sačuvaj palac Aspect Ratio");
define('MANAGE_GALLERY_SHOW_TITLES', "Prikaži Naslovi");
define('MANAGE_GALLERY_DISABLE_SORT', "Onemogući Sortiranje");
define('MANAGE_GALLERY_DELETE_IMAGE', "Brisanje slike");
define('MANAGE_GALLERY_SAVE_SORT_ORDER', "Uštedite razvrstavanja");
define('MANAGE_GALLERY_PUBLISH_MSG', "Kliknite na &#39;Update&#39; objaviti <br /> preneseni slike.");
// Popup Messages:
define('MANAGE_GALLERY_UPDATE_SUCCESS_MSG', "Sve slike su mijenjati i postavke su spremljene.");
define('MANAGE_GALLERY_UPDATE_FAIL_ERR', "Došlo je do pogreške mijenjanje veličine slike ili spremanja postavki.");
define('MANAGE_GALLERY_UPLOAD_SUCCESS_MSG', "prenesena je Vaša slika (s).");
define('MANAGE_GALLERY_UPLOAD_FAIL_ERR', "Došlo je do pogreške prilikom prijenosa sliku (e).");
define('MANAGE_GALLERY_UPLOAD_NOT_IMAGE_ERR', "Datoteka koju pokušavate prenijeti nije slika.");
define('MANAGE_GALLERY_UPLOAD_TOO_BIG_ERR', "Datoteka koju pokušavate prenijeti prevelika.");
define('MANAGE_GALLERY_UPDATE_TITLE_SUCCESS_MSG', "Naslov je spremljena.");
define('MANAGE_GALLERY_DELETE_IMAGE_CONFIRM_1_MSG', "Jeste li sigurni da želite izbrisati sliku");
define('MANAGE_GALLERY_DELETE_IMAGE_CONFIRM_2_MSG', "?");
define('MANAGE_GALLERY_DELETE_IMAGE_SUCCESS_MSG', "Slika je izbrisana.");
define('MANAGE_GALLERY_DELETE_IMAGE_FAIL_ERR', "Došlo je do pogreške prilikom brisanja slike.");
define('MANAGE_GALLERY_SAVING_PARAMS_MSG', "Spremanje parametara i promjenu veličine slike, molimo pričekajte ...");
define('MANAGE_GALLERY_UPLOADING_IMAGES_MSG', "Prijenos, molimo pričekajte ...");
define('MANAGE_GALLERY_NOT_SAVED_MSG', "Redoslijed sortiranja nije spremljen. Da li želite spremiti redoslijed sortiranja?");
define('MANAGE_GALLERY_SAVE_SORT_ORDER_SUCCESS_MSG', "Slika Redoslijed sortiranja je spremljena.");
define('MANAGE_GALLERY_SAVE_SORT_ORDER_FAIL_ERR', "Došlo je do pogreške prilikom spremanja kakve slike.");
?>

==> breeze_website_builder_6.6.18.tar.gz: manage/plugins/lang/gallery/hr.php <==
<?php
////////////////////////////////////////////////////////////////////////
// Breeze Website Builder
// Copyright Silver Dolphin Solutions, LLC, Edward Lemmers, P.E.
// For licensing, see license.txt.
// Created: 3/1/2015	ELL

///////////////////////// Manage Gallery Parameters /////////////////////////
// Buttons:
define('MANAGE_GALLERY_HEADING', "Upravljanje Lightbox gallary Parametri");
define('MANAGE_GALLERY_MANAGE_GALLERY_BTN', "Upravljanje galerija");
// Console Text:
define('MANAGE_GALLERY_FULL_WIDTH', "U punoj veličini Širina slike");
define('MANAGE_GALLERY_FULL_HEIGHT', "U punoj veličini Visina slike");
define('MANAGE_GALLERY_THUMB_WIDTH', "Minijatura Širina slike");
define('MANAGE_GALLERY_THUMB_HEIGHT', "Minijatura Visina slike");
define('MANAGE_GALLERY_PRESERVE_THUMB_ASPECT', "Sačuvaj palac Aspect Ratio");
define('MANAGE_GALLERY_SHOW_TITLES', "Prikaži Naslovi");
define('MANAGE_GALLERY_DISABLE_SORT', "Onemogući Sortiranje");
define('MANAGE_GALLERY_DELETE_IMAGE', "Brisanje slike");
define('MANAGE_GALLERY_SAVE_SORT_ORDER', "Uštedite razvrstavanja");
define('MANAGE_GALLERY_PUBLISH_MSG', "Kliknite na &#39;Update&#39; objaviti <br /> preneseni slike.");
// Popup Messages:
define('MANAGE_GALLERY_UPDATE_SUCCESS_MSG', "Sve slike su mijenjati i postavke su spremljene.");
define('MANAGE_GALLERY_UPDATE_FAIL_ERR', "Došlo je do pogreške mijenjanje veličine slike ili spremanja postavki.");
define('MANAGE_GALLERY_UPLOAD_SUCCESS_MSG', "prenesena je Vaša slika (s).");
define('MANAGE_GALLERY_UPLOAD_FAIL_ERR', "Došlo je do pogreške prilikom prijenosa sliku (e).");
define('MANAGE_GALLERY_UPLOAD_NOT_IMAGE_ERR', "Datoteka koju pokušavate prenijeti nije slika.");
define('MANAGE_GALLERY_UPLOAD_TOO_BIG_ERR', "Datoteka koju pokušavate prenijeti prevelika.");
define('MANAGE_GALLERY_UPDATE_TITLE_SUCCESS_MSG', "Naslov je spremljena.");
define('MANAGE_GALLERY_DELETE_IMAGE_CONFIRM_1_MSG', "Jeste li sigurni da želite izbrisati sliku");
define('MANAGE_GALLERY_DELETE_IMAGE_CONFIRM_2_MSG', "?");
define('MANAGE_GALLERY_DELETE_IMAGE_SUCCESS_MSG', "Slika je izbrisana.");
define('MANAGE_GALLERY_DELETE_IMAGE_FAIL_ERR', "Došlo je do pogreške prilikom brisanja slike.");
define('MANAGE_GALLERY_SAVING_PARAMS_MSG', "Spremanje parametara i promjenu veličine slike, molimo pričekajte ...");
define('MANAGE_GALLERY_UPLOADING_IMAGES_MSG', "Prijenos, molimo pričekajte ...");
define('MANAGE_GALLERY_NOT_SAVED_MSG', "Redoslijed sortiranja nije spremljen. Da li želite spremiti redoslijed sortiranja?");
define('MANAGE_GALLERY_SAVE_SORT_ORDER_SUCCESS_MSG', "Slika Redoslijed sortiranja je spremljena.");
define('MANAGE_GALLERY_SAVE_SORT_ORDER_FAIL_ERR', "Došlo je do pogreške prilikom spremanja kakve slike.");
define('MANAGE_GALLERY_UPLOAD_BIGGER_THAN_ALLOWED_ERR', "Datoteka koju pokušavate učitati veća je od postavki PHP &quot;upload_max_filesize&quot; ili &quot;post_max_size&quot;. Da biste povećali ta ograničenja, obratite se administratoru sustava.");
?>
